# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from kater import Kater, AsyncKater
from tests.utils import assert_matches_type
from kater.types.v1.connections.client.mcp import (
    ServerListResponse,
    ServerCreateResponse,
    ServerUpdateResponse,
    ServerDiscoverResponse,
    ServerRediscoverResponse,
    ServerUpdateConfigResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestServers:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.create(
            name="x",
            server_url="server_url",
            slug="x",
        )
        assert_matches_type(ServerCreateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.create(
            name="x",
            server_url="server_url",
            slug="x",
            api_key="api_key",
            auth_type="api_key",
            description="description",
            oauth_authorize_url="oauth_authorize_url",
            oauth_client_id="oauth_client_id",
            oauth_client_secret="oauth_client_secret",
            oauth_revoke_url="oauth_revoke_url",
            oauth_scopes_requested="oauth_scopes_requested",
            oauth_token_url="oauth_token_url",
            terms_acknowledged=True,
            transport="auto",
        )
        assert_matches_type(ServerCreateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Kater) -> None:
        response = client.v1.connections.client.mcp.servers.with_raw_response.create(
            name="x",
            server_url="server_url",
            slug="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = response.parse()
        assert_matches_type(ServerCreateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Kater) -> None:
        with client.v1.connections.client.mcp.servers.with_streaming_response.create(
            name="x",
            server_url="server_url",
            slug="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = response.parse()
            assert_matches_type(ServerCreateResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.update(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ServerUpdateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.update(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            allowed_capabilities=[
                {
                    "description": "description",
                    "input_schema": {"foo": "bar"},
                    "name": "name",
                }
            ],
            enabled=True,
        )
        assert_matches_type(ServerUpdateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Kater) -> None:
        response = client.v1.connections.client.mcp.servers.with_raw_response.update(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = response.parse()
        assert_matches_type(ServerUpdateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Kater) -> None:
        with client.v1.connections.client.mcp.servers.with_streaming_response.update(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = response.parse()
            assert_matches_type(ServerUpdateResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Kater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            client.v1.connections.client.mcp.servers.with_raw_response.update(
                mcp_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.list()
        assert_matches_type(ServerListResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Kater) -> None:
        response = client.v1.connections.client.mcp.servers.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = response.parse()
        assert_matches_type(ServerListResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Kater) -> None:
        with client.v1.connections.client.mcp.servers.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = response.parse()
            assert_matches_type(ServerListResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Kater) -> None:
        response = client.v1.connections.client.mcp.servers.with_raw_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = response.parse()
        assert server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Kater) -> None:
        with client.v1.connections.client.mcp.servers.with_streaming_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = response.parse()
            assert server is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Kater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            client.v1.connections.client.mcp.servers.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_discover(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.discover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ServerDiscoverResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_discover(self, client: Kater) -> None:
        response = client.v1.connections.client.mcp.servers.with_raw_response.discover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = response.parse()
        assert_matches_type(ServerDiscoverResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_discover(self, client: Kater) -> None:
        with client.v1.connections.client.mcp.servers.with_streaming_response.discover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = response.parse()
            assert_matches_type(ServerDiscoverResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_discover(self, client: Kater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            client.v1.connections.client.mcp.servers.with_raw_response.discover(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_rediscover(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.rediscover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ServerRediscoverResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_rediscover(self, client: Kater) -> None:
        response = client.v1.connections.client.mcp.servers.with_raw_response.rediscover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = response.parse()
        assert_matches_type(ServerRediscoverResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_rediscover(self, client: Kater) -> None:
        with client.v1.connections.client.mcp.servers.with_streaming_response.rediscover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = response.parse()
            assert_matches_type(ServerRediscoverResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_rediscover(self, client: Kater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            client.v1.connections.client.mcp.servers.with_raw_response.rediscover(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_api_key(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.update_api_key(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            api_key="x",
        )
        assert server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update_api_key(self, client: Kater) -> None:
        response = client.v1.connections.client.mcp.servers.with_raw_response.update_api_key(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            api_key="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = response.parse()
        assert server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update_api_key(self, client: Kater) -> None:
        with client.v1.connections.client.mcp.servers.with_streaming_response.update_api_key(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            api_key="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = response.parse()
            assert server is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update_api_key(self, client: Kater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            client.v1.connections.client.mcp.servers.with_raw_response.update_api_key(
                mcp_id="",
                api_key="x",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_config(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.update_config(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ServerUpdateConfigResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_config_with_all_params(self, client: Kater) -> None:
        server = client.v1.connections.client.mcp.servers.update_config(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            auth_type="api_key",
            description="description",
            name="x",
            oauth_authorize_url="oauth_authorize_url",
            oauth_client_id="oauth_client_id",
            oauth_client_secret="oauth_client_secret",
            oauth_revoke_url="oauth_revoke_url",
            oauth_scopes_requested="oauth_scopes_requested",
            oauth_token_url="oauth_token_url",
            server_url="server_url",
            transport="auto",
        )
        assert_matches_type(ServerUpdateConfigResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update_config(self, client: Kater) -> None:
        response = client.v1.connections.client.mcp.servers.with_raw_response.update_config(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = response.parse()
        assert_matches_type(ServerUpdateConfigResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update_config(self, client: Kater) -> None:
        with client.v1.connections.client.mcp.servers.with_streaming_response.update_config(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = response.parse()
            assert_matches_type(ServerUpdateConfigResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update_config(self, client: Kater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            client.v1.connections.client.mcp.servers.with_raw_response.update_config(
                mcp_id="",
            )


class TestAsyncServers:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.create(
            name="x",
            server_url="server_url",
            slug="x",
        )
        assert_matches_type(ServerCreateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.create(
            name="x",
            server_url="server_url",
            slug="x",
            api_key="api_key",
            auth_type="api_key",
            description="description",
            oauth_authorize_url="oauth_authorize_url",
            oauth_client_id="oauth_client_id",
            oauth_client_secret="oauth_client_secret",
            oauth_revoke_url="oauth_revoke_url",
            oauth_scopes_requested="oauth_scopes_requested",
            oauth_token_url="oauth_token_url",
            terms_acknowledged=True,
            transport="auto",
        )
        assert_matches_type(ServerCreateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncKater) -> None:
        response = await async_client.v1.connections.client.mcp.servers.with_raw_response.create(
            name="x",
            server_url="server_url",
            slug="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = await response.parse()
        assert_matches_type(ServerCreateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncKater) -> None:
        async with async_client.v1.connections.client.mcp.servers.with_streaming_response.create(
            name="x",
            server_url="server_url",
            slug="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = await response.parse()
            assert_matches_type(ServerCreateResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.update(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ServerUpdateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.update(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            allowed_capabilities=[
                {
                    "description": "description",
                    "input_schema": {"foo": "bar"},
                    "name": "name",
                }
            ],
            enabled=True,
        )
        assert_matches_type(ServerUpdateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncKater) -> None:
        response = await async_client.v1.connections.client.mcp.servers.with_raw_response.update(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = await response.parse()
        assert_matches_type(ServerUpdateResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncKater) -> None:
        async with async_client.v1.connections.client.mcp.servers.with_streaming_response.update(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = await response.parse()
            assert_matches_type(ServerUpdateResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncKater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            await async_client.v1.connections.client.mcp.servers.with_raw_response.update(
                mcp_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.list()
        assert_matches_type(ServerListResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncKater) -> None:
        response = await async_client.v1.connections.client.mcp.servers.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = await response.parse()
        assert_matches_type(ServerListResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncKater) -> None:
        async with async_client.v1.connections.client.mcp.servers.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = await response.parse()
            assert_matches_type(ServerListResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncKater) -> None:
        response = await async_client.v1.connections.client.mcp.servers.with_raw_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = await response.parse()
        assert server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncKater) -> None:
        async with async_client.v1.connections.client.mcp.servers.with_streaming_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = await response.parse()
            assert server is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncKater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            await async_client.v1.connections.client.mcp.servers.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_discover(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.discover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ServerDiscoverResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_discover(self, async_client: AsyncKater) -> None:
        response = await async_client.v1.connections.client.mcp.servers.with_raw_response.discover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = await response.parse()
        assert_matches_type(ServerDiscoverResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_discover(self, async_client: AsyncKater) -> None:
        async with async_client.v1.connections.client.mcp.servers.with_streaming_response.discover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = await response.parse()
            assert_matches_type(ServerDiscoverResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_discover(self, async_client: AsyncKater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            await async_client.v1.connections.client.mcp.servers.with_raw_response.discover(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_rediscover(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.rediscover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ServerRediscoverResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_rediscover(self, async_client: AsyncKater) -> None:
        response = await async_client.v1.connections.client.mcp.servers.with_raw_response.rediscover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = await response.parse()
        assert_matches_type(ServerRediscoverResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_rediscover(self, async_client: AsyncKater) -> None:
        async with async_client.v1.connections.client.mcp.servers.with_streaming_response.rediscover(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = await response.parse()
            assert_matches_type(ServerRediscoverResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_rediscover(self, async_client: AsyncKater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            await async_client.v1.connections.client.mcp.servers.with_raw_response.rediscover(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_api_key(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.update_api_key(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            api_key="x",
        )
        assert server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update_api_key(self, async_client: AsyncKater) -> None:
        response = await async_client.v1.connections.client.mcp.servers.with_raw_response.update_api_key(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            api_key="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = await response.parse()
        assert server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update_api_key(self, async_client: AsyncKater) -> None:
        async with async_client.v1.connections.client.mcp.servers.with_streaming_response.update_api_key(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            api_key="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = await response.parse()
            assert server is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update_api_key(self, async_client: AsyncKater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            await async_client.v1.connections.client.mcp.servers.with_raw_response.update_api_key(
                mcp_id="",
                api_key="x",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_config(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.update_config(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ServerUpdateConfigResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_config_with_all_params(self, async_client: AsyncKater) -> None:
        server = await async_client.v1.connections.client.mcp.servers.update_config(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            auth_type="api_key",
            description="description",
            name="x",
            oauth_authorize_url="oauth_authorize_url",
            oauth_client_id="oauth_client_id",
            oauth_client_secret="oauth_client_secret",
            oauth_revoke_url="oauth_revoke_url",
            oauth_scopes_requested="oauth_scopes_requested",
            oauth_token_url="oauth_token_url",
            server_url="server_url",
            transport="auto",
        )
        assert_matches_type(ServerUpdateConfigResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update_config(self, async_client: AsyncKater) -> None:
        response = await async_client.v1.connections.client.mcp.servers.with_raw_response.update_config(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        server = await response.parse()
        assert_matches_type(ServerUpdateConfigResponse, server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update_config(self, async_client: AsyncKater) -> None:
        async with async_client.v1.connections.client.mcp.servers.with_streaming_response.update_config(
            mcp_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            server = await response.parse()
            assert_matches_type(ServerUpdateConfigResponse, server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update_config(self, async_client: AsyncKater) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_id` but received ''"):
            await async_client.v1.connections.client.mcp.servers.with_raw_response.update_config(
                mcp_id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from datetime import datetime

from ...._models import BaseModel

__all__ = ["OAuthHandleCallbackResponse"]


class OAuthHandleCallbackResponse(BaseModel):
    """Response after successful OAuth callback."""

    connected_at: datetime

    connection_status: str

    mcp_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from .oauth import (
    OAuthResource,
    AsyncOAuthResource,
    OAuthResourceWithRawResponse,
    AsyncOAuthResourceWithRawResponse,
    OAuthResourceWithStreamingResponse,
    AsyncOAuthResourceWithStreamingResponse,
)
from ......_types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ......_utils import path_template, maybe_transform, async_maybe_transform
from .credentials import (
    CredentialsResource,
    AsyncCredentialsResource,
    CredentialsResourceWithRawResponse,
    AsyncCredentialsResourceWithRawResponse,
    CredentialsResourceWithStreamingResponse,
    AsyncCredentialsResourceWithStreamingResponse,
)
from ......_compat import cached_property
from ......_resource import SyncAPIResource, AsyncAPIResource
from ......_response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ......_base_client import make_request_options
from ......types.v1.connections.tenant import mcp_list_params, mcp_get_audit_history_params
from ......types.v1.connections.tenant.mcp_list_response import McpListResponse
from ......types.v1.connections.tenant.mcp_get_audit_history_response import McpGetAuditHistoryResponse

__all__ = ["McpResource", "AsyncMcpResource"]


class McpResource(SyncAPIResource):
    """Tenant MCP credential management"""

    @cached_property
    def credentials(self) -> CredentialsResource:
        """Tenant MCP credential management"""
        return CredentialsResource(self._client)

    @cached_property
    def oauth(self) -> OAuthResource:
        """Tenant MCP credential management"""
        return OAuthResource(self._client)

    @cached_property
    def with_raw_response(self) -> McpResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kater-ai/kater-python-sdk#accessing-raw-response-data-eg-headers
        """
        return McpResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> McpResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kater-ai/kater-python-sdk#with_streaming_response
        """
        return McpResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        tenant_id: str,
        tenant_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> McpListResponse:
        """
        List active MCP servers for the client with per-user connection status.

        Returns servers where status='active', enabled=true, deleted_at IS NULL. For
        auth_type='none' servers, connection_status is always "connected". For other
        servers, connection status reflects the user's credential state.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/api/v1/tenant/mcp",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "tenant_id": tenant_id,
                        "tenant_user_id": tenant_user_id,
                    },
                    mcp_list_params.McpListParams,
                ),
                security={"propel_auth": True},
            ),
            cast_to=McpListResponse,
        )

    def get_audit_history(
        self,
        mcp_id: str,
        *,
        tenant_id: str,
        tenant_user_id: str,
        cursor: Optional[str] | Omit = omit,
        limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> McpGetAuditHistoryResponse:
        """
        Get credential audit history for the current user's MCP server connection.

        Returns audit records across all credential rotations using the shared
        credential_key, ordered by created_at DESC.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return self._get(
            path_template("/api/v1/tenant/mcp/{mcp_id}/audit", mcp_id=mcp_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "tenant_id": tenant_id,
                        "tenant_user_id": tenant_user_id,
                        "cursor": cursor,
                        "limit": limit,
                    },
                    mcp_get_audit_history_params.McpGetAuditHistoryParams,
                ),
                security={"propel_auth": True},
            ),
            cast_to=McpGetAuditHistoryResponse,
        )


class AsyncMcpResource(AsyncAPIResource):
    """Tenant MCP credential management"""

    @cached_property
    def credentials(self) -> AsyncCredentialsResource:
        """Tenant MCP credential management"""
        return AsyncCredentialsResource(self._client)

    @cached_property
    def oauth(self) -> AsyncOAuthResource:
        """Tenant MCP credential management"""
        return AsyncOAuthResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncMcpResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kater-ai/kater-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncMcpResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMcpResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kater-ai/kater-python-sdk#with_streaming_response
        """
        return AsyncMcpResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        tenant_id: str,
        tenant_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> McpListResponse:
        """
        List active MCP servers for the client with per-user connection status.

        Returns servers where status='active', enabled=true, deleted_at IS NULL. For
        auth_type='none' servers, connection_status is always "connected". For other
        servers, connection status reflects the user's credential state.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/api/v1/tenant/mcp",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "tenant_id": tenant_id,
                        "tenant_user_id": tenant_user_id,
                    },
                    mcp_list_params.McpListParams,
                ),
                security={"propel_auth": True},
            ),
            cast_to=McpListResponse,
        )

    async def get_audit_history(
        self,
        mcp_id: str,
        *,
        tenant_id: str,
        tenant_user_id: str,
        cursor: Optional[str] | Omit = omit,
        limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> McpGetAuditHistoryResponse:
        """
        Get credential audit history for the current user's MCP server connection.

        Returns audit records across all credential rotations using the shared
        credential_key, ordered by created_at DESC.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return await self._get(
            path_template("/api/v1/tenant/mcp/{mcp_id}/audit", mcp_id=mcp_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "tenant_id": tenant_id,
                        "tenant_user_id": tenant_user_id,
                        "cursor": cursor,
                        "limit": limit,
                    },
                    mcp_get_audit_history_params.McpGetAuditHistoryParams,
                ),
                security={"propel_auth": True},
            ),
            cast_to=McpGetAuditHistoryResponse,
        )


class McpResourceWithRawResponse:
    def __init__(self, mcp: McpResource) -> None:
        self._mcp = mcp

        self.list = to_raw_response_wrapper(
            mcp.list,
        )
        self.get_audit_history = to_raw_response_wrapper(
            mcp.get_audit_history,
        )

    @cached_property
    def credentials(self) -> CredentialsResourceWithRawResponse:
        """Tenant MCP credential management"""
        return CredentialsResourceWithRawResponse(self._mcp.credentials)

    @cached_property
    def oauth(self) -> OAuthResourceWithRawResponse:
        """Tenant MCP credential management"""
        return OAuthResourceWithRawResponse(self._mcp.oauth)


class AsyncMcpResourceWithRawResponse:
    def __init__(self, mcp: AsyncMcpResource) -> None:
        self._mcp = mcp

        self.list = async_to_raw_response_wrapper(
            mcp.list,
        )
        self.get_audit_history = async_to_raw_response_wrapper(
            mcp.get_audit_history,
        )

    @cached_property
    def credentials(self) -> AsyncCredentialsResourceWithRawResponse:
        """Tenant MCP credential management"""
        return AsyncCredentialsResourceWithRawResponse(self._mcp.credentials)

    @cached_property
    def oauth(self) -> AsyncOAuthResourceWithRawResponse:
        """Tenant MCP credential management"""
        return AsyncOAuthResourceWithRawResponse(self._mcp.oauth)


class McpResourceWithStreamingResponse:
    def __init__(self, mcp: McpResource) -> None:
        self._mcp = mcp

        self.list = to_streamed_response_wrapper(
            mcp.list,
        )
        self.get_audit_history = to_streamed_response_wrapper(
            mcp.get_audit_history,
        )

    @cached_property
    def credentials(self) -> CredentialsResourceWithStreamingResponse:
        """Tenant MCP credential management"""
        return CredentialsResourceWithStreamingResponse(self._mcp.credentials)

    @cached_property
    def oauth(self) -> OAuthResourceWithStreamingResponse:
        """Tenant MCP credential management"""
        return OAuthResourceWithStreamingResponse(self._mcp.oauth)


class AsyncMcpResourceWithStreamingResponse:
    def __init__(self, mcp: AsyncMcpResource) -> None:
        self._mcp = mcp

        self.list = async_to_streamed_response_wrapper(
            mcp.list,
        )
        self.get_audit_history = async_to_streamed_response_wrapper(
            mcp.get_audit_history,
        )

    @cached_property
    def credentials(self) -> AsyncCredentialsResourceWithStreamingResponse:
        """Tenant MCP credential management"""
        return AsyncCredentialsResourceWithStreamingResponse(self._mcp.credentials)

    @cached_property
    def oauth(self) -> AsyncOAuthResourceWithStreamingResponse:
        """Tenant MCP credential management"""
        return AsyncOAuthResourceWithStreamingResponse(self._mcp.oauth)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from typing_extensions import Literal

from ......_models import BaseModel

__all__ = ["ServerRediscoverResponse"]


class ServerRediscoverResponse(BaseModel):
    """Response model for MCP server capability discovery."""

    capabilities: List[Dict[str, object]]

    capabilities_count: int

    status: Literal["pending_setup", "active"]
    """Lifecycle status of an MCP server registration."""

    can_skip: Optional[bool] = None

    error: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable, Optional
from typing_extensions import Required, Annotated, TypedDict

from ......_utils import PropertyInfo

__all__ = ["ServerUpdateParams", "AllowedCapability"]


class ServerUpdateParams(TypedDict, total=False):
    allowed_capabilities: Optional[Iterable[AllowedCapability]]
    """Capabilities to expose as LLM tools"""

    enabled: Optional[bool]
    """Enable/disable toggle"""


class AllowedCapability(TypedDict, total=False):
    """A capability selected by the admin for LLM tool exposure."""

    description: Required[str]

    input_schema: Required[Annotated[Dict[str, object], PropertyInfo(alias="inputSchema")]]

    name: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime

from ....._models import BaseModel

__all__ = ["McpGetAuditHistoryResponse", "Item"]


class Item(BaseModel):
    """Response model for a single credential audit record."""

    id: str

    action: str

    actor_id: str

    created_at: datetime

    actor_ip: Optional[str] = None

    metadata: Optional[Dict[str, object]] = None


class McpGetAuditHistoryResponse(BaseModel):
    """Paginated response for credential audit history."""

    items: List[Item]

    next_cursor: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["McpListParams"]


class McpListParams(TypedDict, total=False):
    tenant_id: Required[str]

    tenant_user_id: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from ....._models import BaseModel

__all__ = ["McpListResponse", "McpListResponseItem"]


class McpListResponseItem(BaseModel):
    """Response model for a tenant-visible MCP server with connection status."""

    auth_type: Literal["api_key", "oauth2", "none"]
    """Authentication type for MCP server connections."""

    connection_status: str

    mcp_id: str

    name: str

    slug: str

    description: Optional[str] = None


McpListResponse: TypeAlias = List[McpListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal

import httpx

from ......_types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ......_utils import path_template, maybe_transform, async_maybe_transform
from ......_compat import cached_property
from ......_resource import SyncAPIResource, AsyncAPIResource
from ......_response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ......_base_client import make_request_options
from ......types.v1.connections.client.mcp import (
    server_create_params,
    server_update_params,
    server_update_config_params,
    server_update_api_key_params,
)
from ......types.v1.connections.client.mcp.server_list_response import ServerListResponse
from ......types.v1.connections.client.mcp.server_create_response import ServerCreateResponse
from ......types.v1.connections.client.mcp.server_update_response import ServerUpdateResponse
from ......types.v1.connections.client.mcp.server_discover_response import ServerDiscoverResponse
from ......types.v1.connections.client.mcp.server_rediscover_response import ServerRediscoverResponse
from ......types.v1.connections.client.mcp.server_update_config_response import ServerUpdateConfigResponse

__all__ = ["ServersResource", "AsyncServersResource"]


class ServersResource(SyncAPIResource):
    """Manage MCP server integrations"""

    @cached_property
    def with_raw_response(self) -> ServersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kater-ai/kater-python-sdk#accessing-raw-response-data-eg-headers
        """
        return ServersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ServersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kater-ai/kater-python-sdk#with_streaming_response
        """
        return ServersResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        server_url: str,
        slug: str,
        api_key: Optional[str] | Omit = omit,
        auth_type: Literal["api_key", "oauth2", "none"] | Omit = omit,
        description: Optional[str] | Omit = omit,
        oauth_authorize_url: Optional[str] | Omit = omit,
        oauth_client_id: Optional[str] | Omit = omit,
        oauth_client_secret: Optional[str] | Omit = omit,
        oauth_revoke_url: Optional[str] | Omit = omit,
        oauth_scopes_requested: Optional[str] | Omit = omit,
        oauth_token_url: Optional[str] | Omit = omit,
        terms_acknowledged: bool | Omit = omit,
        transport: Literal["auto", "streamable_http", "sse"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerCreateResponse:
        """
        Register a new MCP server for the client organization.

        Validates URL safety (SSRF prevention), slug format, and OAuth fields. The MCP
        server is NOT contacted during registration.

        Args:
          name: Display name

          server_url: HTTPS URL of the MCP server

          slug: Unique snake_case identifier

          api_key: API key (for auth_type=api_key). Stored as shared client-level credential.

          auth_type: Authentication type

          description: Optional description

          oauth_authorize_url: OAuth2 authorize URL

          oauth_client_id: OAuth2 client ID

          oauth_client_secret: OAuth2 client secret (encrypted)

          oauth_revoke_url: OAuth2 revoke URL (optional)

          oauth_scopes_requested: OAuth2 scopes

          oauth_token_url: OAuth2 token URL

          terms_acknowledged: Must be true to accept security terms

          transport: Transport protocol

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/v1/client/mcp/servers",
            body=maybe_transform(
                {
                    "name": name,
                    "server_url": server_url,
                    "slug": slug,
                    "api_key": api_key,
                    "auth_type": auth_type,
                    "description": description,
                    "oauth_authorize_url": oauth_authorize_url,
                    "oauth_client_id": oauth_client_id,
                    "oauth_client_secret": oauth_client_secret,
                    "oauth_revoke_url": oauth_revoke_url,
                    "oauth_scopes_requested": oauth_scopes_requested,
                    "oauth_token_url": oauth_token_url,
                    "terms_acknowledged": terms_acknowledged,
                    "transport": transport,
                },
                server_create_params.ServerCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerCreateResponse,
        )

    def update(
        self,
        mcp_id: str,
        *,
        allowed_capabilities: Optional[Iterable[server_update_params.AllowedCapability]] | Omit = omit,
        enabled: Optional[bool] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerUpdateResponse:
        """
        Activate an MCP server by selecting capabilities to expose.

        Validates that all submitted capability names exist in the server's discovered
        capabilities. Sets status to 'active' when allowed_capabilities is non-empty.

        Args:
          allowed_capabilities: Capabilities to expose as LLM tools

          enabled: Enable/disable toggle

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return self._put(
            path_template("/api/v1/client/mcp/servers/{mcp_id}", mcp_id=mcp_id),
            body=maybe_transform(
                {
                    "allowed_capabilities": allowed_capabilities,
                    "enabled": enabled,
                },
                server_update_params.ServerUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerUpdateResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerListResponse:
        """
        List all MCP servers for the authenticated client.

        RLS automatically scopes results to the client's organization. Only non-deleted
        servers are returned.
        """
        return self._get(
            "/api/v1/client/mcp/servers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerListResponse,
        )

    def delete(
        self,
        mcp_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Soft-delete an MCP server and cascade to credential settings.

        Cascades:

        1.

        All mcp_credential_settings rows set to status='revoked' + deleted_at
        2. OAuth client secret credential soft-deleted (if exists)
        3. MCP server row soft-deleted

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            path_template("/api/v1/client/mcp/servers/{mcp_id}", mcp_id=mcp_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=NoneType,
        )

    def discover(
        self,
        mcp_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerDiscoverResponse:
        """
        Discover capabilities from a registered MCP server.

        For api_key servers with a stored credential, uses the API key for discovery.
        Discovery does NOT change server status.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return self._post(
            path_template("/api/v1/client/mcp/servers/{mcp_id}/discover", mcp_id=mcp_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerDiscoverResponse,
        )

    def rediscover(
        self,
        mcp_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerRediscoverResponse:
        """
        Re-discover capabilities and merge with existing data.

        New capabilities are added. Existing capabilities that are in
        allowed_capabilities preserve their is_write classification. The
        allowed_capabilities list and status are NOT modified.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return self._post(
            path_template("/api/v1/client/mcp/servers/{mcp_id}/rediscover", mcp_id=mcp_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerRediscoverResponse,
        )

    def update_api_key(
        self,
        mcp_id: str,
        *,
        api_key: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Replace the shared API key credential for an api_key MCP server.

        Soft-deletes the old credential and creates a new one.

        Args:
          api_key: New API key value

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            path_template("/api/v1/client/mcp/servers/{mcp_id}/api-key", mcp_id=mcp_id),
            body=maybe_transform({"api_key": api_key}, server_update_api_key_params.ServerUpdateAPIKeyParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=NoneType,
        )

    def update_config(
        self,
        mcp_id: str,
        *,
        auth_type: Optional[Literal["api_key", "oauth2", "none"]] | Omit = omit,
        description: Optional[str] | Omit = omit,
        name: Optional[str] | Omit = omit,
        oauth_authorize_url: Optional[str] | Omit = omit,
        oauth_client_id: Optional[str] | Omit = omit,
        oauth_client_secret: Optional[str] | Omit = omit,
        oauth_revoke_url: Optional[str] | Omit = omit,
        oauth_scopes_requested: Optional[str] | Omit = omit,
        oauth_token_url: Optional[str] | Omit = omit,
        server_url: Optional[str] | Omit = omit,
        transport: Optional[Literal["auto", "streamable_http", "sse"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerUpdateConfigResponse:
        """
        Update the configuration of a registered MCP server.

        Slug is not editable (used in tool naming). Changing server_url or auth_type
        resets server to pending_setup and revokes all tenant credential settings.

        Args:
          auth_type: Authentication type for MCP server connections.

          transport: Transport protocol for MCP server communication.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return self._patch(
            path_template("/api/v1/client/mcp/servers/{mcp_id}/config", mcp_id=mcp_id),
            body=maybe_transform(
                {
                    "auth_type": auth_type,
                    "description": description,
                    "name": name,
                    "oauth_authorize_url": oauth_authorize_url,
                    "oauth_client_id": oauth_client_id,
                    "oauth_client_secret": oauth_client_secret,
                    "oauth_revoke_url": oauth_revoke_url,
                    "oauth_scopes_requested": oauth_scopes_requested,
                    "oauth_token_url": oauth_token_url,
                    "server_url": server_url,
                    "transport": transport,
                },
                server_update_config_params.ServerUpdateConfigParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerUpdateConfigResponse,
        )


class AsyncServersResource(AsyncAPIResource):
    """Manage MCP server integrations"""

    @cached_property
    def with_raw_response(self) -> AsyncServersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kater-ai/kater-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncServersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncServersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kater-ai/kater-python-sdk#with_streaming_response
        """
        return AsyncServersResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        server_url: str,
        slug: str,
        api_key: Optional[str] | Omit = omit,
        auth_type: Literal["api_key", "oauth2", "none"] | Omit = omit,
        description: Optional[str] | Omit = omit,
        oauth_authorize_url: Optional[str] | Omit = omit,
        oauth_client_id: Optional[str] | Omit = omit,
        oauth_client_secret: Optional[str] | Omit = omit,
        oauth_revoke_url: Optional[str] | Omit = omit,
        oauth_scopes_requested: Optional[str] | Omit = omit,
        oauth_token_url: Optional[str] | Omit = omit,
        terms_acknowledged: bool | Omit = omit,
        transport: Literal["auto", "streamable_http", "sse"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerCreateResponse:
        """
        Register a new MCP server for the client organization.

        Validates URL safety (SSRF prevention), slug format, and OAuth fields. The MCP
        server is NOT contacted during registration.

        Args:
          name: Display name

          server_url: HTTPS URL of the MCP server

          slug: Unique snake_case identifier

          api_key: API key (for auth_type=api_key). Stored as shared client-level credential.

          auth_type: Authentication type

          description: Optional description

          oauth_authorize_url: OAuth2 authorize URL

          oauth_client_id: OAuth2 client ID

          oauth_client_secret: OAuth2 client secret (encrypted)

          oauth_revoke_url: OAuth2 revoke URL (optional)

          oauth_scopes_requested: OAuth2 scopes

          oauth_token_url: OAuth2 token URL

          terms_acknowledged: Must be true to accept security terms

          transport: Transport protocol

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/v1/client/mcp/servers",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "server_url": server_url,
                    "slug": slug,
                    "api_key": api_key,
                    "auth_type": auth_type,
                    "description": description,
                    "oauth_authorize_url": oauth_authorize_url,
                    "oauth_client_id": oauth_client_id,
                    "oauth_client_secret": oauth_client_secret,
                    "oauth_revoke_url": oauth_revoke_url,
                    "oauth_scopes_requested": oauth_scopes_requested,
                    "oauth_token_url": oauth_token_url,
                    "terms_acknowledged": terms_acknowledged,
                    "transport": transport,
                },
                server_create_params.ServerCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerCreateResponse,
        )

    async def update(
        self,
        mcp_id: str,
        *,
        allowed_capabilities: Optional[Iterable[server_update_params.AllowedCapability]] | Omit = omit,
        enabled: Optional[bool] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerUpdateResponse:
        """
        Activate an MCP server by selecting capabilities to expose.

        Validates that all submitted capability names exist in the server's discovered
        capabilities. Sets status to 'active' when allowed_capabilities is non-empty.

        Args:
          allowed_capabilities: Capabilities to expose as LLM tools

          enabled: Enable/disable toggle

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return await self._put(
            path_template("/api/v1/client/mcp/servers/{mcp_id}", mcp_id=mcp_id),
            body=await async_maybe_transform(
                {
                    "allowed_capabilities": allowed_capabilities,
                    "enabled": enabled,
                },
                server_update_params.ServerUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerUpdateResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerListResponse:
        """
        List all MCP servers for the authenticated client.

        RLS automatically scopes results to the client's organization. Only non-deleted
        servers are returned.
        """
        return await self._get(
            "/api/v1/client/mcp/servers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerListResponse,
        )

    async def delete(
        self,
        mcp_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Soft-delete an MCP server and cascade to credential settings.

        Cascades:

        1.

        All mcp_credential_settings rows set to status='revoked' + deleted_at
        2. OAuth client secret credential soft-deleted (if exists)
        3. MCP server row soft-deleted

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            path_template("/api/v1/client/mcp/servers/{mcp_id}", mcp_id=mcp_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=NoneType,
        )

    async def discover(
        self,
        mcp_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerDiscoverResponse:
        """
        Discover capabilities from a registered MCP server.

        For api_key servers with a stored credential, uses the API key for discovery.
        Discovery does NOT change server status.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return await self._post(
            path_template("/api/v1/client/mcp/servers/{mcp_id}/discover", mcp_id=mcp_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerDiscoverResponse,
        )

    async def rediscover(
        self,
        mcp_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerRediscoverResponse:
        """
        Re-discover capabilities and merge with existing data.

        New capabilities are added. Existing capabilities that are in
        allowed_capabilities preserve their is_write classification. The
        allowed_capabilities list and status are NOT modified.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return await self._post(
            path_template("/api/v1/client/mcp/servers/{mcp_id}/rediscover", mcp_id=mcp_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerRediscoverResponse,
        )

    async def update_api_key(
        self,
        mcp_id: str,
        *,
        api_key: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Replace the shared API key credential for an api_key MCP server.

        Soft-deletes the old credential and creates a new one.

        Args:
          api_key: New API key value

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            path_template("/api/v1/client/mcp/servers/{mcp_id}/api-key", mcp_id=mcp_id),
            body=await async_maybe_transform(
                {"api_key": api_key}, server_update_api_key_params.ServerUpdateAPIKeyParams
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=NoneType,
        )

    async def update_config(
        self,
        mcp_id: str,
        *,
        auth_type: Optional[Literal["api_key", "oauth2", "none"]] | Omit = omit,
        description: Optional[str] | Omit = omit,
        name: Optional[str] | Omit = omit,
        oauth_authorize_url: Optional[str] | Omit = omit,
        oauth_client_id: Optional[str] | Omit = omit,
        oauth_client_secret: Optional[str] | Omit = omit,
        oauth_revoke_url: Optional[str] | Omit = omit,
        oauth_scopes_requested: Optional[str] | Omit = omit,
        oauth_token_url: Optional[str] | Omit = omit,
        server_url: Optional[str] | Omit = omit,
        transport: Optional[Literal["auto", "streamable_http", "sse"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ServerUpdateConfigResponse:
        """
        Update the configuration of a registered MCP server.

        Slug is not editable (used in tool naming). Changing server_url or auth_type
        resets server to pending_setup and revokes all tenant credential settings.

        Args:
          auth_type: Authentication type for MCP server connections.

          transport: Transport protocol for MCP server communication.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mcp_id:
            raise ValueError(f"Expected a non-empty value for `mcp_id` but received {mcp_id!r}")
        return await self._patch(
            path_template("/api/v1/client/mcp/servers/{mcp_id}/config", mcp_id=mcp_id),
            body=await async_maybe_transform(
                {
                    "auth_type": auth_type,
                    "description": description,
                    "name": name,
                    "oauth_authorize_url": oauth_authorize_url,
                    "oauth_client_id": oauth_client_id,
                    "oauth_client_secret": oauth_client_secret,
                    "oauth_revoke_url": oauth_revoke_url,
                    "oauth_scopes_requested": oauth_scopes_requested,
                    "oauth_token_url": oauth_token_url,
                    "server_url": server_url,
                    "transport": transport,
                },
                server_update_config_params.ServerUpdateConfigParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                security={"propel_auth": True},
            ),
            cast_to=ServerUpdateConfigResponse,
        )


class ServersResourceWithRawResponse:
    def __init__(self, servers: ServersResource) -> None:
        self._servers = servers

        self.create = to_raw_response_wrapper(
            servers.create,
        )
        self.update = to_raw_response_wrapper(
            servers.update,
        )
        self.list = to_raw_response_wrapper(
            servers.list,
        )
        self.delete = to_raw_response_wrapper(
            servers.delete,
        )
        self.discover = to_raw_response_wrapper(
            servers.discover,
        )
        self.rediscover = to_raw_response_wrapper(
            servers.rediscover,
        )
        self.update_api_key = to_raw_response_wrapper(
            servers.update_api_key,
        )
        self.update_config = to_raw_response_wrapper(
            servers.update_config,
        )


class AsyncServersResourceWithRawResponse:
    def __init__(self, servers: AsyncServersResource) -> None:
        self._servers = servers

        self.create = async_to_raw_response_wrapper(
            servers.create,
        )
        self.update = async_to_raw_response_wrapper(
            servers.update,
        )
        self.list = async_to_raw_response_wrapper(
            servers.list,
        )
        self.delete = async_to_raw_response_wrapper(
            servers.delete,
        )
        self.discover = async_to_raw_response_wrapper(
            servers.discover,
        )
        self.rediscover = async_to_raw_response_wrapper(
            servers.rediscover,
        )
        self.update_api_key = async_to_raw_response_wrapper(
            servers.update_api_key,
        )
        self.update_config = async_to_raw_response_wrapper(
            servers.update_config,
        )


class ServersResourceWithStreamingResponse:
    def __init__(self, servers: ServersResource) -> None:
        self._servers = servers

        self.create = to_streamed_response_wrapper(
            servers.create,
        )
        self.update = to_streamed_response_wrapper(
            servers.update,
        )
        self.list = to_streamed_response_wrapper(
            servers.list,
        )
        self.delete = to_streamed_response_wrapper(
            servers.delete,
        )
        self.discover = to_streamed_response_wrapper(
            servers.discover,
        )
        self.rediscover = to_streamed_response_wrapper(
            servers.rediscover,
        )
        self.update_api_key = to_streamed_response_wrapper(
            servers.update_api_key,
        )
        self.update_config = to_streamed_response_wrapper(
            servers.update_config,
        )


class AsyncServersResourceWithStreamingResponse:
    def __init__(self, servers: AsyncServersResource) -> None:
        self._servers = servers

        self.create = async_to_streamed_response_wrapper(
            servers.create,
        )
        self.update = async_to_streamed_response_wrapper(
            servers.update,
        )
        self.list = async_to_streamed_response_wrapper(
            servers.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            servers.delete,
        )
        self.discover = async_to_streamed_response_wrapper(
            servers.discover,
        )
        self.rediscover = async_to_streamed_response_wrapper(
            servers.rediscover,
        )
        self.update_api_key = async_to_streamed_response_wrapper(
            servers.update_api_key,
        )
        self.update_config = async_to_streamed_response_wrapper(
            servers.update_config,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .mcp import (
    McpResource,
    AsyncMcpResource,
    McpResourceWithRawResponse,
    AsyncMcpResourceWithRawResponse,
    McpResourceWithStreamingResponse,
    AsyncMcpResourceWithStreamingResponse,
)
from .client import (
    ClientResource,
    AsyncClientResource,
    ClientResourceWithRawResponse,
    AsyncClientResourceWithRawResponse,
    ClientResourceWithStreamingResponse,
    AsyncClientResourceWithStreamingResponse,
)

__all__ = [
    "McpResource",
    "AsyncMcpResource",
    "McpResourceWithRawResponse",
    "AsyncMcpResourceWithRawResponse",
    "McpResourceWithStreamingResponse",
    "AsyncMcpResourceWithStreamingResponse",
    "ClientResource",
    "AsyncClientResource",
    "ClientResourceWithRawResponse",
    "AsyncClientResourceWithRawResponse",
    "ClientResourceWithStreamingResponse",
    "AsyncClientResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ......_models import BaseModel

__all__ = ["OAuthInitiateResponse"]


class OAuthInitiateResponse(BaseModel):
    """Response model containing the OAuth authorization URL for the frontend."""

    authorize_url: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["McpGetAuditHistoryParams"]


class McpGetAuditHistoryParams(TypedDict, total=False):
    tenant_id: Required[str]

    tenant_user_id: Required[str]

    cursor: Optional[str]

    limit: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .oauth_handle_callback_params import OAuthHandleCallbackParams as OAuthHandleCallbackParams
from .oauth_handle_callback_response import OAuthHandleCallbackResponse as OAuthHandleCallbackResponse
